@@ -57,9 +57,15 @@ class DriverSpecificProbUberMLE(GenericLikelihoodModel):
                  same_impact=False,
                  overall_demean = False,
                  twoway_fixed_effects = 'dummy',
+                 endog_data=None,
+                 exog_data=None,
                  **kwargs):
-
-        super().__init__(endog = np.ones((len(data),1)), exog= np.ones((len(data), 2)), **kwargs)
+        
+        print("Initializing...")
+        super().__init__(endog =np.ones((exog_data.shape[0], 1)), exog= np.ones((exog_data.shape[0],2)), **kwargs)
+        
+        self.df_model = exog_data.shape[1]
+        self.df_resid = exog_data.shape[0] - exog_data.shape[1] + 1
 
         self.classifier_pred = classifier_pred
         self.classifier_ind = classifier_ind
@@ -526,7 +532,17 @@ class DriverSpecificProbUberMLE(GenericLikelihoodModel):
                 )
 
             start_params = np.append(np.append(start_params[:-1], res_dummies), start_params[-1])
-            
+        
+        if kwds.get('cov_type') is None:
+            cov_type='cluster'
+            cov_kwds = {'groups' : self.df.gaul_class,
+                        'df_correction' : True,
+                        'use_correction' : True}
+        else:
+            cov_type = kwds.pop('cov_type', None)
+            cov_kwds = kwds.pop('cov_kwds', None) 
+
+         
         optimize = super().fit(
             method=method,
             start_params=start_params,
@@ -535,6 +551,9 @@ class DriverSpecificProbUberMLE(GenericLikelihoodModel):
             eps=1e-08,
             ftol=1e-10,
             bounds=self.bounds(sigma_bound=sigma_bound),
+            cov_type= cov_type,
+            cov_kwds = cov_kwds,
+            use_t=True,
             **kwds
         )
         # self._start_params(show_ols=show_ols)
